@@ -200,7 +200,7 @@ def print_examples_table(examples: Dict[Text, Any]):
 async def list_examples(
     project_id: Text,
     language: Text,
-    prepared: Text,
+    prepared: bool,
     type: Text,
     intent: Text,
     page_number: int,
